@@ -24,9 +24,9 @@ __all__ = [
 
 __title__ = "bcrypt"
 __summary__ = "Modern password hashing for your software and your servers"
-__uri__ = "https://github.com/dstufft/bcrypt/"
+__uri__ = "https://github.com/pyca/bcrypt/"
 
-__version__ = "1.0.1"
+__version__ = "1.1.0"
 
 __author__ = "Donald Stufft"
 __email__ = "donald@stufft.io"
